@@ -5,7 +5,7 @@ from .enums.goal import Goal
 from .enums.logic import Logic
 from .enums.enemizer import Enemizer
 from .enums.start_location import StartLocation
-from .enums.level import Level
+#from .enums.level import Level
 
 
 class RandomizerData:
@@ -14,10 +14,10 @@ class RandomizerData:
                  logic: Logic = Logic.COMPLETABLE, statues: str = "4", enemizer: Enemizer = Enemizer.NONE,
                  start_location: StartLocation = StartLocation.SOUTH_CAPE, firebird: bool = False, ohko: bool = False,
                  red_jewel_madness: bool = False, allow_glitches: bool = False, boss_shuffle: bool = False,
-                 open_mode: bool = False, level: Level = Level.INTERMEDIATE, overworld_shuffle: bool = False, dungeon_shuffle: bool = False):
+                 open_mode: bool = False, overworld_shuffle: bool = False, dungeon_shuffle: bool = False):
         self.seed = seed
         self.difficulty = difficulty
-        self.level = level
+#        self.level = level
         self.start_location = start_location
         self.goal = goal
         self.logic = logic
